package com.lyg.tools.controller;

import com.lyg.tools.common.FileUtil;
import com.lyg.tools.common.ResponseBean;
import com.lyg.tools.common.StringUtil;
import io.swagger.annotations.Api;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;

import java.util.HashMap;
import java.util.Map;

@Api(tags = "文件上传")
@RestController
@RequestMapping("/")
public class UploadController {

    @Autowired
    FileUtil fileUtil;


    /**
     * 通用端上传文件
     *
     * @param projectId 应用Id
     * @return
     * @throws Exception
     */
    @PostMapping("/upload/{projectId}")
    public ResponseBean uploadAdmin(@RequestParam(value = "file") MultipartFile file,
                                    @RequestParam(value = "fileType") String fileType,
                                    @PathVariable(value = "projectId") String projectId) throws Exception {

        Map<String, Object> res = new HashMap<>();
        String fileName = file.getOriginalFilename();
        String path = fileUtil.saveFile(file, projectId);
        res.put("attachUrl", path);
        res.put("attachName", fileName);
        res.put("fileType", fileType);
        return ResponseBean.success(res);
    }

    /**
     * 通过 Base64 上传文件
     *
     * @param projectId 应用Id
     * @return
     * @throws Exception
     */
    @PostMapping("/upload/base64/{projectId}")
    public ResponseBean uploadBase64(
            @PathVariable(value = "projectId") String projectId,
            @RequestParam(value = "base64") String base64,
            @RequestParam(value = "fileName", defaultValue = "unknown.jpg") String fileName
    ) throws Exception {

        Map<String, Object> res = new HashMap<>();
        byte[] bytes = StringUtil.base64ToBytes(base64);

        String path = fileUtil.saveFile(bytes, fileName, projectId);
        res.put("url", path);

        return ResponseBean.success(res);
    }


}
